@@ -14,7 +14,7 @@
 
 """oslo.i18n integration module.
 
-See http://docs.openstack.org/developer/oslo.i18n/usage.html .
+See https://docs.openstack.org/oslo.i18n/latest/user/index.html.
 
 """
 
@@ -37,4 +37,4 @@ _P = _translators.plural_form
 
 
 def get_available_languages():
-        return oslo_i18n.get_available_languages(DOMAIN)
+    return oslo_i18n.get_available_languages(DOMAIN)
