@@ -71,7 +71,7 @@ class CreateVIM(tackerV10.CreateCommand):
                     config_param = yaml.load(vim_config,
                                              Loader=yaml.SafeLoader)
                 except yaml.YAMLError as e:
-                    raise exceptions.InvalidInput(e)
+                    raise exceptions.InvalidInput(reason=e)
         vim_obj = body[self.resource]
         try:
             auth_url = config_param.pop('auth_url')
@@ -117,9 +117,10 @@ class UpdateVIM(tackerV10.UpdateCommand):
             with open(parsed_args.config_file) as f:
                 config_yaml = f.read()
             try:
-                config_param = yaml.load(config_yaml)
+                config_param = yaml.load(config_yaml,
+                                         Loader=yaml.SafeLoader)
             except yaml.YAMLError as e:
-                raise exceptions.InvalidInput(e)
+                raise exceptions.InvalidInput(reason=e)
         vim_obj = body[self.resource]
         if config_param is not None:
             vim_utils.args2body_vim(config_param, vim_obj)
